"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const AST_1 = require("../parser/AST");
const ContentPath_node_1 = require("../parser/ContentPath.node");
const Tagger_1 = require("../tagger/Tagger");
describe('Tagger', () => {
    const jsQueryScm = `
  (
    (comment)* @doc
    .
    (method_definition
      name: (property_identifier) @name.definition.method) @definition.method
    (#not-eq? @name.definition.method "constructor")
    (#strip! @doc "^[\\s\\*/]+|^[\\s\\*/]$")
    (#select-adjacent! @doc @definition.method)
  )
  
  (
    (comment)* @doc
    .
    [
      (class
        name: (_) @name.definition.class)
      (class_declaration
        name: (_) @name.definition.class)
    ] @definition.class
    (#strip! @doc "^[\\s\\*/]+|^[\\s\\*/]$")
    (#select-adjacent! @doc @definition.class)
  )
  
  (
    (comment)* @doc
    .
    [
      (function
        name: (identifier) @name.definition.function)
      (function_declaration
        name: (identifier) @name.definition.function)
      (generator_function
        name: (identifier) @name.definition.function)
      (generator_function_declaration
        name: (identifier) @name.definition.function)
    ] @definition.function
    (#strip! @doc "^[\\s\\*/]+|^[\\s\\*/]$")
    (#select-adjacent! @doc @definition.function)
  )
  
  (
    (comment)* @doc
    .
    (lexical_declaration
      (variable_declarator
        name: (identifier) @name.definition.function
        value: [(arrow_function) (function)]) @definition.function)
    (#strip! @doc "^[\\s\\*/]+|^[\\s\\*/]$")
    (#select-adjacent! @doc @definition.function)
  )
  
  (
    (comment)* @doc
    .
    (variable_declaration
      (variable_declarator
        name: (identifier) @name.definition.function
        value: [(arrow_function) (function)]) @definition.function)
    (#strip! @doc "^[\\s\\*/]+|^[\\s\\*/]$")
    (#select-adjacent! @doc @definition.function)
  )
  
  (assignment_expression
    left: [
      (identifier) @name.definition.function
      (member_expression
        property: (property_identifier) @name.definition.function)
    ]
    right: [(arrow_function) (function)]
  ) @definition.function
  
  (pair
    key: (property_identifier) @name.definition.function
    value: [(arrow_function) (function)]) @definition.function
  
  (
    (call_expression
      function: (identifier) @name.reference.call) @reference.call
    (#not-match? @name.reference.call "^(require)$")
  )
  
  (call_expression
    function: (member_expression
      property: (property_identifier) @name.reference.call)
    arguments: (_) @reference.call)
  
  (new_expression
    constructor: (_) @name.reference.class) @reference.class
  
  `;
    describe('read for JavaScript file contents', () => {
        it('should return an empty array when there are no captures', () => __awaiter(void 0, void 0, void 0, function* () {
            const contentPath = new ContentPath_node_1.NodeContentPath();
            const language = 'JavaScript';
            const ast = yield AST_1.AST.createFromCode({ relPath: 'test.js', code: 'let x = 1;' }, contentPath.getWasmURL(language), language);
            const tagger = Tagger_1.Tagger.create(ast, jsQueryScm);
            const result = tagger === null || tagger === void 0 ? void 0 : tagger.read();
            expect(result).toEqual([]);
        }));
        it('should return a single reference', () => __awaiter(void 0, void 0, void 0, function* () {
            const contentPath = new ContentPath_node_1.NodeContentPath();
            const language = 'JavaScript';
            const ast = yield AST_1.AST.createFromCode({
                relPath: 'test.js',
                code: `let x = 1;
      console.log(x);`,
            }, contentPath.getWasmURL(language), language);
            const tagger = Tagger_1.Tagger.create(ast, jsQueryScm);
            const result = tagger === null || tagger === void 0 ? void 0 : tagger.read();
            expect(result).toEqual([
                {
                    relPath: 'test.js',
                    text: 'log',
                    kind: 'ref',
                    start: {
                        ln: 1,
                        col: 14,
                    },
                    end: {
                        ln: 1,
                        col: 17,
                    },
                },
            ]);
        }));
    });
});
//# sourceMappingURL=Tagger.test.js.map