"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_node_1 = require("../index.node");
class NumCharsSizer {
    constructor(sizeInChars) {
        this.sizeInChars = sizeInChars;
    }
    fits(content) {
        return content.length <= this.sizeInChars;
    }
}
describe('getHighlightsThatFit', () => {
    it('should return the concatenated highlights for the top percentile of non-chat tags', () => __awaiter(void 0, void 0, void 0, function* () {
        const contextSizer = new NumCharsSizer(100);
        const chatSources = [
            {
                relPath: 'chat1.js',
                code: `
          console.log(add(1, 2));
        `,
            },
            {
                relPath: 'chat2.js',
                code: `
          console.log(multiply(3, 1));
        `,
            },
        ];
        const otherSources = [
            {
                relPath: 'file1.js',
                code: `
function add(a, b) {
  return a + b;
}
console.log(add(1, 2));
`,
            },
            {
                relPath: 'file2.js',
                code: `
function subtract(a, b) {
  return a - b;
}
console.log(subtract(3, 1));
`,
            },
            {
                relPath: 'file3.js',
                code: `
function multiply(a, b) {
  return a * b;
}
console.log(multiply(2, 3));
`,
            },
        ];
        const result = yield (0, index_node_1.getHighlightsThatFit)(contextSizer, chatSources, otherSources);
        expect(result).toBe(`
file1.js
⋮...
█function add(a, b) {
⋮...

file3.js
⋮...
█function multiply(a, b) {
⋮...
`);
    }));
});
describe('getFileOutlineHighlights', () => {
    it('should return the concatenated outlines for all the files', () => __awaiter(void 0, void 0, void 0, function* () {
        const sources = [
            {
                relPath: 'file1.js',
                code: `function add(a, b) {
      return a + b;
    }`,
            },
            {
                relPath: 'file2.js',
                code: `function subtract(a, b) {
      return a - b;
    }`,
            },
        ];
        const result = yield (0, index_node_1.getOutlines)(sources);
        expect(result).toBe(`
file1.js
█function add(a, b) {
⋮...

file2.js
█function subtract(a, b) {
⋮...
`);
    }));
});
//# sourceMappingURL=index.node.test.js.map