"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CodeTagExtractor_1 = require("../tagger/CodeTagExtractor");
const ContentPath_node_1 = require("../parser/ContentPath.node");
const DefRef_1 = require("../tagger/DefRef");
const codefixture_1 = require("./codefixture");
const Outliner_1 = require("../outliner/Outliner");
function generateFileOutlineFromTags(fileTags, code) {
    return __awaiter(this, void 0, void 0, function* () {
        const highlighter = yield Outliner_1.Outliner.create(fileTags, code);
        if (!highlighter)
            return;
        return highlighter.toHighlights();
    });
}
describe('outliner', () => {
    let extractor;
    let contentPath;
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        contentPath = new ContentPath_node_1.NodeContentPath();
        extractor = new CodeTagExtractor_1.CodeTagExtractor('', contentPath);
    }));
    describe('create', () => {
        it('should create a new DefRef instance', () => __awaiter(void 0, void 0, void 0, function* () {
            const defRef = yield DefRef_1.DefRef.create(extractor, codefixture_1.test_typescript_code);
            expect(defRef).toBeInstanceOf(DefRef_1.DefRef);
        }));
    });
    describe('highlight outline', () => {
        it('should return python definitions', () => __awaiter(void 0, void 0, void 0, function* () {
            const defRef = yield DefRef_1.DefRef.create(extractor, codefixture_1.test_python_code);
            const defs = defRef.defs;
            const outline = yield generateFileOutlineFromTags(defs, codefixture_1.test_python_code.code);
            expect(outline).toBe(codefixture_1.expected_outlines_python);
        }));
        it('should return typescript definitions', () => __awaiter(void 0, void 0, void 0, function* () {
            const defRef = yield DefRef_1.DefRef.create(extractor, codefixture_1.test_typescript_code);
            const defs = defRef.defs;
            if (!defs || defs.length === 0)
                return;
            const outline = yield generateFileOutlineFromTags(defs, codefixture_1.test_typescript_code.code);
            expect(outline).toBe(codefixture_1.expected_outlines_typescript);
        }));
    });
});
//# sourceMappingURL=outliner.test.js.map