"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodelineScoper = void 0;
const LineScoper_1 = require("./LineScoper");
class CodelineScoper {
    static create(numLines) {
        const scopes = new Array(numLines)
            .fill([])
            .map(() => []);
        return new CodelineScoper(numLines, scopes);
    }
    constructor(numLines, scopes) {
        this.numLines = numLines;
        this.scopes = scopes;
    }
    withScopeDataInitialized(node, depth = 0) {
        const startLine = node.startPosition.row;
        const endLine = node.endPosition.row;
        const size = endLine - startLine;
        if (size) {
            this.scopes[startLine].push([size, startLine, endLine]);
        }
        node.children.forEach(child => this.withScopeDataInitialized(child, depth + 1));
        return this;
    }
    toDominantScopes(codeLines) {
        const scopes = new Array(this.numLines);
        for (let i = 0; i < this.numLines; i++) {
            const scopesI = this.scopes[i].sort((a, b) => {
                for (let i = 0; i < 3; i++) {
                    if (a[i] < b[i])
                        return -1;
                    else if (a[i] > b[i])
                        return 1;
                }
                return 0;
            });
            scopes[i] = scopesI.length > 1 ? scopesI[0].slice(1) : [0, -1];
        }
        const scopeStarts = new Array(this.numLines).fill(new Set());
        scopes.forEach(([startLine, endLine]) => {
            for (let i = startLine; i <= endLine; i++) {
                scopeStarts[i].add(startLine);
            }
        });
        return new LineScoper_1.LineScoper(codeLines, scopeStarts);
    }
}
exports.CodelineScoper = CodelineScoper;
//# sourceMappingURL=CodelineScoper.js.map