"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Highlights = void 0;
const lodash_1 = __importDefault(require("lodash"));
const ranker_1 = require("../ranker");
const Highlighter_1 = require("./Highlighter");
class Highlights {
    static create(chatSources, otherSources, contentPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const allSources = [...chatSources, ...otherSources];
            const rankedTags = yield (0, ranker_1.createRankedTags)({ sources: allSources, contentPath: contentPath });
            if (!rankedTags)
                return;
            const chatRelPaths = chatSources.map(source => source.relPath);
            return new Highlights(rankedTags.without(chatRelPaths), allSources, contentPath);
        });
    }
    constructor(rankedTags, allSources, contentPath) {
        this.rankedTags = rankedTags;
        this.allSources = allSources;
        this.contentPath = contentPath;
    }
    toCodeHighlights(percentile) {
        return __awaiter(this, void 0, void 0, function* () {
            const topTags = this.rankedTags.toTags();
            const maxTags = lodash_1.default.round(percentile * topTags.length);
            const mapTags = topTags.slice(0, maxTags);
            const sortedTags = lodash_1.default.orderBy(mapTags, ['relPath', 'start.ln'], ['asc', 'asc']);
            const groupedTags = lodash_1.default.groupBy(sortedTags, tag => tag.relPath);
            const fileHighlights = yield Promise.all(lodash_1.default.values(groupedTags).map((tags) => __awaiter(this, void 0, void 0, function* () {
                const relPath = tags[0].relPath;
                const code = this.allSources.find(source => source.relPath === relPath).code;
                const highlighter = yield Highlighter_1.Highlighter.create(tags, code, this.contentPath);
                if (!highlighter)
                    return;
                return highlighter.toHighlights();
            })));
            return lodash_1.default.join(fileHighlights, '');
        });
    }
}
exports.Highlights = Highlights;
//# sourceMappingURL=Highlights.js.map