"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOutlines = exports.getHighlightsThatFit = void 0;
const index_shared_1 = require("./index.shared");
const ContentPath_node_1 = require("./parser/ContentPath.node");
/**
 * Generates highlights for a source set by selecting the top ranked tags from non-chat sources,
 * that will fit in the context.
 *
 * It ranks all tags across the source set using PageRank, filters out tags from chat sources,
 * groups them by file, and generates highlights for each file.
 *
 * If the concatenated highlights do not fit in context a binary search on percentile is carried out
 * until a result is found that fits.
 *
 * @param contextSizer: - The context sizer that determines if the highlights will fit in the context.
 * @param chatSources - The source code files that are from chat.
 * @param otherSources - The source code files that are not from chat.
 * @returns The concatenated highlights for the top percentile of non-chat tags.
 */
function getHighlightsThatFit(contextSizer, chatSources, otherSources) {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, index_shared_1.highlightsThatFit)(contextSizer, chatSources, otherSources, new ContentPath_node_1.NodeContentPath());
    });
}
exports.getHighlightsThatFit = getHighlightsThatFit;
/**
 * Generates an outline for a set of files by only displaying the definition lines.
 *
 * The outlines are concatenated and returned.
 *
 * @param sources - An array of objects, each having the path and source code for a file
 * @returns The concatenated outlines for all the files.
 */
function getOutlines(sources) {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, index_shared_1.outlines)({ sources: sources, contentPath: new ContentPath_node_1.NodeContentPath() });
    });
}
exports.getOutlines = getOutlines;
//# sourceMappingURL=index.node.js.map