"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Outliner = void 0;
const CodeHighlighter_1 = require("../highlighter/CodeHighlighter");
class Outliner {
    static create(fileTags, code) {
        return __awaiter(this, void 0, void 0, function* () {
            const relPath = fileTags[0].relPath;
            const linesOfInterest = fileTags.map(tag => tag.start.ln);
            const source = { relPath: relPath, code: code };
            return Outliner.createFromLOI(linesOfInterest, source);
        });
    }
    static createFromLOI(linesOfInterest, source) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Outliner(source, linesOfInterest);
        });
    }
    constructor(source, linesOfInterest) {
        this.source = source;
        this.linesOfInterest = linesOfInterest;
    }
    toHighlights() {
        const codeLines = this.source.code.split('\n');
        const highlighter = new CodeHighlighter_1.CodeHighlighter(codeLines, Array.from(this.linesOfInterest).sort((a, b) => a - b), Array.from(new Set(this.linesOfInterest)).sort((a, b) => a - b));
        if (!highlighter)
            return;
        const highlights = highlighter.toFormattedString();
        return `\n${this.source.relPath}\n${highlights}`;
    }
}
exports.Outliner = Outliner;
//# sourceMappingURL=Outliner.js.map