"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Outlines = void 0;
const lodash_1 = __importDefault(require("lodash"));
const tagger_1 = require("../tagger");
const CodeTagExtractor_1 = require("../tagger/CodeTagExtractor");
const Outliner_1 = require("./Outliner");
class Outlines {
    static create(sourceSet) {
        return __awaiter(this, void 0, void 0, function* () {
            const extractor = new CodeTagExtractor_1.CodeTagExtractor('', sourceSet.contentPath);
            const defs = yield Promise.all(sourceSet.sources.map((source) => __awaiter(this, void 0, void 0, function* () {
                return tagger_1.DefRef.create(extractor, source);
            })));
            return new Outlines(defs.map(defRef => defRef.defs), sourceSet);
        });
    }
    constructor(defs, sourceSet) {
        this.defs = defs;
        this.sourceSet = sourceSet;
    }
    toCodeOutlines() {
        return __awaiter(this, void 0, void 0, function* () {
            const codeOutlines = yield Promise.all(lodash_1.default.zip(this.defs, this.sourceSet.sources)
                .filter(([tags, _sources]) => {
                return tags;
            })
                .map(([tags, source]) => __awaiter(this, void 0, void 0, function* () {
                const highlighter = yield Outliner_1.Outliner.create(tags, source.code);
                if (!highlighter)
                    return;
                return highlighter.toHighlights();
            })));
            return lodash_1.default.join(codeOutlines, '');
        });
    }
}
exports.Outlines = Outlines;
//# sourceMappingURL=Outlines.js.map