"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWasmPath = exports.getQueryFileName = exports.getLanguage = void 0;
const extToLang = {
    py: 'Python',
    js: 'JavaScript',
    mjs: 'JavaScript',
    go: 'Go',
    c: 'C',
    cc: 'C++',
    cs: 'C#',
    cpp: 'C++',
    el: 'Elisp',
    ex: 'Elixir',
    elm: 'Elm',
    java: 'Java',
    ml: 'Ocaml',
    php: 'PHP',
    ql: 'QL',
    rb: 'Ruby',
    rs: 'Rust',
    ts: 'TypeScript',
};
const lang2QryNameString = {
    C: 'c',
    'C#': 'c_sharp',
    'C++': 'cpp',
    Elisp: 'elisp',
    Elixir: 'elixir',
    Elm: 'elm',
    Go: 'go',
    Java: 'java',
    JavaScript: 'javascript',
    Ocaml: 'ocaml',
    PHP: 'php',
    Python: 'python',
    QL: 'ql',
    Ruby: 'ruby',
    Rust: 'rust',
    TypeScript: 'typescript',
};
function getLanguage(filename) {
    const extension = filename.split('.').pop();
    if (!extension || !(extension in extToLang))
        return;
    return extToLang[extension];
}
exports.getLanguage = getLanguage;
function getQueryFileName(lang) {
    if (!(lang in lang2QryNameString))
        return;
    return `tree-sitter-${lang2QryNameString[lang]}-tags.scm`;
}
exports.getQueryFileName = getQueryFileName;
function getWasmPath(lang) {
    if (!(lang in lang2QryNameString))
        return;
    return `tree-sitter-${lang2QryNameString[lang]}.wasm`;
}
exports.getWasmPath = getWasmPath;
//# sourceMappingURL=lang-utils.js.map