"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagRanker = void 0;
const graphology_1 = __importDefault(require("graphology"));
const pagerank_1 = __importDefault(require("graphology-metrics/centrality/pagerank"));
const RankedTags_1 = require("./RankedTags");
class TagRanker {
    constructor(tags) {
        this.tags = tags;
    }
    pagerank() {
        class _Counter extends Map {
            constructor(iterable = []) {
                super();
                for (let item of iterable) {
                    this.add(item);
                }
            }
            add(item) {
                this.set(item, (this.get(item) || 0) + 1);
            }
        }
        const tags = this.tags;
        const G = new graphology_1.default();
        tags.identifiers.forEach(ident => {
            const definers = tags.defines.get(ident);
            const counter = new _Counter(tags.references.get(ident));
            counter.forEach((numRefs, referencer) => {
                definers.forEach(definer => {
                    G.mergeEdge(referencer, definer, { weight: numRefs, ident: ident });
                });
            });
        });
        pagerank_1.default.assign(G);
        const rankedDefinitionsMap = new Map();
        G.nodes().forEach(referencer => {
            const refRank = G.getNodeAttribute(referencer, 'pagerank');
            const totalWeight = G.edges(referencer).reduce((total, edge) => total + G.getEdgeAttribute(edge, 'weight'), 0);
            G.edges(referencer).map(edge => {
                const definer = G.target(edge);
                const data = G.getEdgeAttributes(edge);
                const defRank = (refRank * data['weight']) / totalWeight;
                const key = `${definer},${data['ident']}`;
                if (!rankedDefinitionsMap.has(key))
                    rankedDefinitionsMap.set(key, 0);
                rankedDefinitionsMap.set(key, rankedDefinitionsMap.get(key) + defRank);
            });
        });
        const rankedFilesMap = G.nodes().reduce((accumulator, node) => {
            accumulator[node] = G.getNodeAttribute(node, 'pagerank');
            return accumulator;
        }, {});
        const rankedDefinitions = Array.from(rankedDefinitionsMap.entries()).sort((a, b) => b[1] - a[1]);
        const rankedFiles = Object.entries(rankedFilesMap).sort((a, b) => b[1] - a[1]);
        return new RankedTags_1.RankedTags(tags.definitions, rankedFiles, rankedDefinitions);
    }
}
exports.TagRanker = TagRanker;
//# sourceMappingURL=TagRanker.js.map