"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CachedFileTagExtractor = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const CodeTagExtractor_1 = require("./CodeTagExtractor");
const ContentPath_node_1 = require("../parser/ContentPath.node");
class CachedFileTagExtractor {
    static create(workspacePath) {
        const cacheFileName = path.join(workspacePath, CachedFileTagExtractor.CACHE_FILE_NAME);
        const cache = fs.existsSync(cacheFileName)
            ? JSON.parse(fs.readFileSync(cacheFileName, 'utf8'))
            : {};
        const extractor = new CodeTagExtractor_1.CodeTagExtractor(workspacePath, new ContentPath_node_1.NodeContentPath());
        return new CachedFileTagExtractor(extractor, cache);
    }
    static getMtime(absPath) {
        try {
            return fs.statSync(absPath).mtimeMs;
        }
        catch (e) {
            return;
        }
    }
    constructor(extractor, cache) {
        this.extractor = extractor;
        this.cache = cache;
    }
    get workspacePath() {
        return this.extractor.workspacePath;
    }
    getAbsPath(relPath) {
        return path.join(this.workspacePath, relPath);
    }
    getTags(relPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const absPath = this.getAbsPath(relPath);
            const fileMtime = CachedFileTagExtractor.getMtime(absPath);
            if (!fileMtime)
                return [];
            const value = this.cache[absPath];
            if (value && value.mtime === fileMtime) {
                return value.data;
            }
            const code = fs.readFileSync(absPath, 'utf8');
            if (!code)
                return [];
            return this.extractor.extractTags({ relPath: relPath, code: code });
        });
    }
    extractTags(source) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.extractor.extractTags(source);
        });
    }
    writeCache() {
        const cacheFileName = path.join(this.workspacePath, CachedFileTagExtractor.CACHE_FILE_NAME);
        fs.writeFileSync(cacheFileName, JSON.stringify(this.cache), 'utf8');
    }
}
exports.CachedFileTagExtractor = CachedFileTagExtractor;
CachedFileTagExtractor.CACHE_FILE_NAME = 'tags.cache.json';
//# sourceMappingURL=CachedFileTagExtractor.js.map