"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeTagExtractor = void 0;
const parser_1 = require("../parser");
const Tagger_1 = require("./Tagger");
const TagQuery_1 = require("./TagQuery");
class CodeTagExtractor {
    constructor(workspacePath, contentPath) {
        this.workspacePath = workspacePath;
        this.contentPath = contentPath;
    }
    extractTags(source) {
        return __awaiter(this, void 0, void 0, function* () {
            const language = (0, parser_1.getLanguage)(source.relPath);
            if (!language)
                return [];
            const wasmPath = this.contentPath.getWasmURL(language);
            const ast = yield parser_1.AST.createFromCode(source, wasmPath, language);
            const tagQuery = new TagQuery_1.TagQuery(this.contentPath);
            const tagger = Tagger_1.Tagger.create(ast, tagQuery.getQuery(language));
            return tagger.read();
        });
    }
}
exports.CodeTagExtractor = CodeTagExtractor;
//# sourceMappingURL=CodeTagExtractor.js.map