"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tagger = void 0;
class Tagger {
    static create(ast, queryScm) {
        return new Tagger(ast, queryScm);
    }
    static _getKind(tag) {
        if (tag.startsWith('name.definition.')) {
            return 'def';
        }
        else if (tag.startsWith('name.reference.')) {
            return 'ref';
        }
        else {
            return;
        }
    }
    constructor(ast, queryScm) {
        this.ast = ast;
        this.queryScm = queryScm;
    }
    read() {
        return this.ast
            .captures(this.queryScm)
            .map(({ node, name }) => {
            const kind = Tagger._getKind(name);
            return kind
                ? {
                    relPath: this.ast.relPath,
                    text: node.text,
                    kind: kind,
                    start: {
                        ln: node.startPosition.row,
                        col: node.startPosition.column,
                    },
                    end: {
                        ln: node.endPosition.row,
                        col: node.endPosition.column,
                    },
                }
                : undefined;
        })
            .filter((tag) => tag !== undefined);
    }
}
exports.Tagger = Tagger;
//# sourceMappingURL=Tagger.js.map