"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefRef = exports.createTags = exports.createDefRefs = exports.createAST = void 0;
const parser_1 = require("../parser");
const lang_utils_1 = require("../parser/lang-utils");
const CodeTagExtractor_1 = require("./CodeTagExtractor");
const DefRef_1 = require("./DefRef");
Object.defineProperty(exports, "DefRef", { enumerable: true, get: function () { return DefRef_1.DefRef; } });
const DefRefs_1 = require("./DefRefs");
function createAST(source, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const language = (0, lang_utils_1.getLanguage)(source.relPath);
        if (!language)
            return;
        const wasmPath = contentPath.getWasmURL(language);
        return parser_1.AST.createFromCode(source, wasmPath, language);
    });
}
exports.createAST = createAST;
function createDefRefs(sourceSet) {
    return __awaiter(this, void 0, void 0, function* () {
        const extractor = new CodeTagExtractor_1.CodeTagExtractor('', sourceSet.contentPath);
        return yield DefRefs_1.DefRefs.create(extractor, sourceSet.sources);
    });
}
exports.createDefRefs = createDefRefs;
function createTags(sourceSet) {
    return __awaiter(this, void 0, void 0, function* () {
        const defRefs = yield createDefRefs(sourceSet);
        if (!defRefs)
            return;
        return defRefs.createTags();
    });
}
exports.createTags = createTags;
//# sourceMappingURL=index.js.map